# [1.2.0](https://github.com/rpesche/cryptopcash/compare/1.1.0...1.2.0) (2019-09-12)


### Features

* add correct version on cryptopcash ([a696e20](https://github.com/rpesche/cryptopcash/commit/a696e20))
* add error dialog triggered with exception ([b905e7e](https://github.com/rpesche/cryptopcash/commit/b905e7e))
* show error dialog when adding invalid crypto currency ([f5b3fbb](https://github.com/rpesche/cryptopcash/commit/f5b3fbb))

# [1.1.0](https://github.com/rpesche/cryptopcash/compare/1.0.1...1.1.0) (2019-09-12)


### Features

* use default config file if not exists ([13b3f64](https://github.com/rpesche/cryptopcash/commit/13b3f64))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)


### Bug Fixes

* upgrade of requests solving a security alert ([e2bedc4](https://github.com/rpesche/cryptopcash/commit/e2bedc4))

## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-09-03)
=======
## [1.0.1](https://github.com/rpesche/cryptopcash/compare/1.0.0...1.0.1) (2019-04-10)
